@@ -3,8 +3,9 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Chromatic and diatonic melodic ornamentation
 
-our $VERSION = '0.0500';
+our $VERSION = '0.0501';
 
+use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
 use MIDI::Simple ();
@@ -203,11 +204,12 @@ sub _find_pitch {
     my ($self, $pitch, $scale) = @_;
     $scale //= $self->_scale;
     my $i = first_index { $_ eq $pitch } @$scale;
-    if ($i == -1) {
+    if ($i < 0) {
         my $enharmonics = $self->_enharmonics;
         $pitch =~ s/^([A-G][#b]?)(\d+)$/$enharmonics->{$1}$2/;
         $i = first_index { $_ eq $pitch } @$scale;
     }
+    croak "Unknown pitch: $pitch" if $i < 0;
     return $i, $pitch;
 }
 
@@ -225,7 +227,7 @@ Music::MelodicDevice::Ornamentation - Chromatic and diatonic melodic ornamentati
 
 =head1 VERSION
 
-version 0.0500
+version 0.0501
 
 =head1 SYNOPSIS
 
@@ -254,7 +256,7 @@ Each returns a note-set specification.  This specification is a list
 of two part array-references: a B<duration> and a B<pitch>.  The list
 B<duration> component is a division of the given duration argument,
 and is based on the arithmetic of each ornament.  The list B<pitch>
-varies around the given pitch argument by the given offset, and also
+can vary around the given pitch argument by the given offset, and also
 depends on the particular ornament re-phrasing.
 
 =head1 ATTRIBUTES
@@ -340,13 +342,15 @@ C<D5 E5 D5>.  A chromatic lower mordent would be C<D5 C#5 D5>.
 
   $spec = $md->slide($duration, $from, $to);
 
-Play each note in the C<chromatic> scale between B<from> and B<to> for
-the given B<duration>.
+Play each note in the C<chromatic> scale between the B<from> and B<to>
+pitches, for the given B<duration>.
 
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/*> programs in this distribution
 
+L<Carp>
+
 L<Data::Dumper::Compact>
 
 L<List::SomeUtils>
